@@ -85,10 +85,7 @@ def from_config(ctx, config_file, verbose):
         os.makedirs(config.dirout)
 
     # initialize loggers.
-    init_mult(name, config.logdir, modules=[__name__, 'reV.econ.econ',
-                                            'reV.config', 'reV.utilities',
-                                            'reV.SAM', 'rex.utilities'],
-              verbose=verbose)
+    init_mult(name, config.logdir, modules=['reV', 'rex'], verbose=verbose)
     cf_files = config.parse_cf_files()
     # Initial log statements
     logger.info('Running reV Econ from config file: "{}"'
@@ -283,9 +280,7 @@ def local(ctx, max_workers, timeout, points_range, verbose):
         dirout = os.path.dirname(cf_file)
 
     # initialize loggers for multiple modules
-    log_modules = [__name__, 'reV.econ.econ', 'reV.generation', 'reV.config',
-                   'reV.utilities', 'reV.SAM', 'reV.handlers', 'rex.utilities']
-    init_mult(name, logdir, modules=log_modules,
+    init_mult(name, logdir, modules=['reV', 'rex'],
               verbose=verbose, node=True)
 
     for key, val in ctx.obj.items():
@@ -496,11 +491,6 @@ def slurm(ctx, nodes, alloc, memory, walltime, feature, module, conda_env,
     append = ctx.obj['APPEND']
     verbose = any([verbose, ctx.obj['VERBOSE']])
 
-    # initialize a logger on the year level
-    log_modules = [__name__, 'reV.econ.econ', 'reV.config', 'reV.utilities',
-                   'reV.SAM', 'rex.utilities']
-    init_mult(name, logdir, modules=log_modules, verbose=verbose)
-
     slurm_manager = ctx.obj.get('SLURM_MANAGER', None)
     if slurm_manager is None:
         slurm_manager = SLURM()
